PrivateKey

Enum PrivateKey 

#[non_exhaustive]
pub enum PrivateKey { Rsa(RsaPrivateKey), EcP256(SecretKey), EcP384(SecretKey), }
A private key for any algorithm supported by the crate.

This key is split from the SigningKey type so that it could be decoded and encoded using the [$dec_trait], [$dec_rsa_trait] and EncodePrivateKey traits.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Rsa(RsaPrivateKey)

PKCS#1 v1.5 RSA private key.



EcP256(SecretKey)

ECDSA with NIST P-256 curve private key.



EcP384(SecretKey)

ECDSA with NIST P-384 curve private key.

Implementations

Source

impl PrivateKey

pub fn read_pem_file(path: impl AsRef<Path>) -> Result<Self, DecodeError>

Tries to parse a PEM file at the specified path as a private key.

pub fn from_pem(pem: &str) -> Result<Self, DecodeError>

Tries to parse an in-memory PEM file as a private key.

pub fn to_public_key(&self) -> PublicKey

Creates a public key from a private key.