#[non_exhaustive]pub enum SigningKey {
RsaWithSha1(SigningKey<Sha1>),
RsaWithSha256(SigningKey<Sha256>),
RsaWithSha384(SigningKey<Sha384>),
EcP256(SigningKey),
EcP384(SigningKey),
}Expand description
A signing key for any algorithm supported by the crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RsaWithSha1(SigningKey<Sha1>)
PKCS#1 v1.5 RSA signing key which uses SHA-1 as the digest.
RsaWithSha256(SigningKey<Sha256>)
PKCS#1 v1.5 RSA signing key which uses SHA-256 as the digest.
RsaWithSha384(SigningKey<Sha384>)
PKCS#1 v1.5 RSA signing key which uses SHA-384 as the digest.
EcP256(SigningKey)
ECDSA/P-256 signing key (uses SHA-256 as the digest primitive).
EcP384(SigningKey)
ECDSA/P-384 signing key (uses SHA-384 as the digest primitive).
Implementations
Sourceimpl SigningKey
impl SigningKey
Sourcepub fn from_key_and_algo(
key: PrivateKey,
algo: Option<DigestAlgo>,
) -> Result<Self, UnsupportedDigest>
pub fn from_key_and_algo( key: PrivateKey, algo: Option<DigestAlgo>, ) -> Result<Self, UnsupportedDigest>
Creates a new SigningKey from a PrivateKey and a DigestAlgo.
If no digest algorithm is provided, a default one is used.
For RSA PKCS#1 v1.5 signatures the default is SHA-384, for elliptic curve algorithms the default and the only supported digest algorithms are SHA-256 for NIST P-256 and SHA-384 for NIST P-384.